@@ -21,7 +21,7 @@ password: 0a8148539c426d7c008433172230b551
 """
 
 def get_time():
-    return str(datetime.datetime.now()).split('.')[0]
+    return str(datetime.datetime.utcnow()).split('.')[0]
 
 def get_host():
     return socket.gethostname().split('.', 1)[0] + " " + str(os.getpid())
@@ -179,7 +179,7 @@ class CAM(object):
         <br>`cam ls worker 30` will list all workers wile each column has at most 30 chars.
         <br>`cam ls task 30` will list all tasks wile each column has at most 30 chars.
         """
-        now = datetime.datetime.now()
+        now = get_time()
         log_info("Server: ", self._conf['server'], ":", str(self._conf['port']), ' v', self.__version__)
         if type is None or type == "task":
             pending = self._redis.lrange("pending", 0, -1)
